import json
from base64 import b64encode


def repo_name(wid, cid):
    return "{}-{}".format(wid, cid)


def change_ref(sid, chid):
    return "{}/{}".format(sid, chid)


def plan_ref(sid, chid):
    return "tf/plan/{}".format(change_ref(sid, chid))


def apply_ref(sid):
    return "tf/apply/{}".format(sid)


def encode_content(content):
    return b64encode(json.dumps(content, sort_keys=True, indent=0).encode()).decode()


from re import match


def valid_id(id_):
    return (
        isinstance(id_, str)
        and 1 <= len(id_) <= 40
        and "/" not in id_
        and id_ not in [".", ".."]
        and not match("__.*__", id_)
    )


def valid_name(name):
    return isinstance(name, str) and 1 <= len(name) <= 50


def valid_repo(repo):
    return isinstance(repo, str) and all(map(valid_id, repo.split("-")))


def valid_asset(asset):
    if isinstance(asset, str):
        parts = list(filter(None, asset.split("/")))
        return len(parts) >= 2 and all(map(valid_id, parts))
    return False


def valid_chid_suffix(suffix):
    return (
        isinstance(suffix, str)
        and 1 <= len(suffix) <= 100
        and match("[a-zA-Z0-9-]+$", suffix)
    )


def valid_chid(chid):
    if isinstance(chid, str):
        parts = chid.split("/")
        return len(parts) == 2 and valid_id(parts[0]) and valid_chid_suffix(parts[1])
    return False


def valid_apply_ref(ref):
    return (
        isinstance(ref, str)
        and ref.startswith("tf/apply")
        and valid_id(ref.split("/")[2])
    )



import setuptools

setuptools.setup(
    name="bluprnt",
    version="0.1.14",
    author="Chris Wacker",
    author_email="chriswacker228@gmail.com",
    description="A small helper package for Blueprint project.",
    packages=setuptools.find_packages(),
    install_requires=["requests", "google-cloud-firestore==1.7.0"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)
